@@ -147,7 +147,7 @@ sampleN.TOST <- function(alpha=0.05, targetpower=0.8, logscale=TRUE, theta0,
     if (missing(theta0)) theta0 <- 0.95
     if (missing(theta2)) theta2=1/theta1
     if ( (theta0<=theta1) | (theta0>=theta2) ) {
-      stop("Null ratio ",theta0," not between margins ",theta1," / ",theta2,"!", 
+      stop("True ratio ",theta0," not between margins ",theta1," / ",theta2,"!", 
            call.=FALSE)
      }
     ltheta1 <- log(theta1)
@@ -160,7 +160,7 @@ sampleN.TOST <- function(alpha=0.05, targetpower=0.8, logscale=TRUE, theta0,
     if (missing(theta0)) theta0 <- 0.05
     if (missing(theta2)) theta2=-theta1
     if ( (theta0<=theta1) | (theta0>=theta2) ) {
-      stop("Null diff. ",theta0," not between margins ",theta1," / ",theta2,"!", 
+      stop("True diff. ",theta0," not between margins ",theta1," / ",theta2,"!", 
            call.=FALSE)
     }
     ltheta1 <- theta1
@@ -172,9 +172,9 @@ sampleN.TOST <- function(alpha=0.05, targetpower=0.8, logscale=TRUE, theta0,
   
   if (print) {
     cat("alpha = ",alpha,", target power = ", targetpower,"\n", sep="")
-    cat("BE margins        =",theta1,"...", theta2,"\n")
-    if (logscale) cat("Null (true) ratio = ",theta0,",  CV = ",CV,"\n", sep="")
-    else          cat("Null (true) diff. = ",theta0,",  CV = ",CV,"\n", sep="")
+    cat("BE margins =",theta1,"...", theta2,"\n")
+    if (logscale) cat("True ratio = ",theta0,",  CV = ",CV,"\n", sep="")
+    else          cat("True diff. = ",theta0,",  CV = ",CV,"\n", sep="")
   }
   
   # start value from large sample approx. (hidden func.)
