@@ -3,9 +3,9 @@
 # --------------------------------------------------------------------------
 print.pwrA <- function(x, digits=4, plotit=TRUE, ...)
 {
-  
+
   if(interactive() && plotit) plot(x)
-  
+
   min.pwr  <- x$minpower
   CV.max   <- max(x$paCV[,"CV"])
   CVmaxI   <- which(x$paCV[,"CV"]==CV.max)
@@ -16,7 +16,7 @@ print.pwrA <- function(x, digits=4, plotit=TRUE, ...)
 
   if (abs(x$paCV[CVmaxI,"pwr"]-min.pwr)>1e-4) CV.max <- NA
   if (abs(x$paCV[CVminI,"pwr"]-min.pwr)>1e-4) CV.min <- NA
-  
+
   if (x$plan[1,"theta0"]<=1) {
     min.theta0 <- min(x$paGMR[,"theta0"])
   } else {
@@ -29,7 +29,7 @@ print.pwrA <- function(x, digits=4, plotit=TRUE, ...)
                    HC =   " (HC/ABEL2)",
                    ANVISA=" (ANVISA/ABEL)",
                    FDA=   " (FDA/RSABE)"
-                  ) 
+                  )
     method <- paste0(method, meth)
   }
   cat("Sample size plan ", method, "\n",sep="")
@@ -58,7 +58,7 @@ print.pwrA <- function(x, digits=4, plotit=TRUE, ...)
 # Author D.Labes, from original code by H. Schuetz
 # reworked by H. Schuetz to avoid overlay of target power line with legend
 # ----------------------------------------------------------------------------
-plot.pwrA <- function(x, pct=TRUE, cols=c("blue", "red"), ...)
+plot.pwrA <- function(x, pct=TRUE, ratiolabel="theta0", cols=c("blue", "red"), ...)
 {
   # make colors between the both given
   mkColors <- function(){
@@ -69,10 +69,10 @@ plot.pwrA <- function(x, pct=TRUE, cols=c("blue", "red"), ...)
     clr  <- clr1[colno]
     return(clr)
   }
-  
+
   if (pct) {
     fact    <- 100
-    ylabtxt <- "% power"
+    ylabtxt <- "power (%)"
     dec     <- 2
     pctsign <- "%"
   }   else {
@@ -80,14 +80,14 @@ plot.pwrA <- function(x, pct=TRUE, cols=c("blue", "red"), ...)
     ylabtxt <- "power"
     dec     <- 4
     pctsign <- ""
-  } 
+  }
 
   n <- nrow(x$paCV)
   # Attention next functiones only if last value is minpower
   minpower    <- fact*x$minpower
   CV.max      <- fact*max(x$paCV[,"CV"])
   CV.min      <- fact*min(x$paCV[,"CV"])
-  
+
   # CV of call of pa.XXX() function
   if (x$method=="ABE") {
     CV  <- fact*x$plan[1,"CV"]
@@ -103,7 +103,7 @@ plot.pwrA <- function(x, pct=TRUE, cols=c("blue", "red"), ...)
   targetpower <- fact*x$plan[1,"Target power"]
   reg         <- x$regulator
   design      <- x$plan[1,"Design"]
-  
+
   mklegend <- function(method){
     if (method=="scABE"){
       algo <- ifelse(reg == "FDA", "RSABE", "ABEL")
@@ -115,40 +115,46 @@ plot.pwrA <- function(x, pct=TRUE, cols=c("blue", "red"), ...)
       bg="white", box.lty=0)
     }
   }
-  
+
   op <- par(no.readonly=TRUE) # save par() options
-  par(mar=c(c(4, 4, 2.5, 0.75))+0.1) # default for B, L, T, R: c(5, 4, 4, 2) + 0.1
-  par(cex.main=0.95, cex.axis=0.95, cex.lab=0.95, mgp=c(2,0.75,0), tcl=-0.2)
-  
-  # plot at a paneel with 4 pieces
+  par(mar=c(c(3.5, 3.5, 2.5, 0.75))+0.1) # bottom, left, top, right
+  par(cex.main=0.95, cex.axis=0.95, cex.lab=0.95, mgp=c(2, 0.75, 0), tcl=-0.2)
+
+  # plot on a panel of 4 pieces
   split.screen(c(2, 2))
-  
+
   screen(1) ### 'Sensitivity' of CV (GMR and n constant) ###
   pwr <- as.numeric(fact*x$paCV[,"pwr"])
   CVs <- as.numeric(fact*x$paCV[,"CV"])
   seg <- length(pwr); s <- seq(seg-1)
   clr <- mkColors()
   xlabtxt <- "CV"
-  if (fact==100) xlabtxt <- "CV %"
+  if (fact==100) xlabtxt <- "CV (%)"
 
-  if (x$method=="ABE"){
+  if (x$method == "ABE") {
     plot(CVs, pwr, type="n",
-         main=paste0("Higher variability\n", "theta0 = ", GMR, ", n = ", n.est),
-         lwd=2, xlab=xlabtxt, ylab=ylabtxt, las=1)
+         main=paste0("Higher variability\n",
+                     "constant: ", ratiolabel, " = ", GMR, ", N = ", n.est),
+         lwd=2, xlab=xlabtxt, ylab="", las=1)
+    mtext(side=2, ylabtxt, line=2.5)
     box()
-    abline(h=c(targetpower, fact*0.8, minpower), lty=3, col="grey50")
+    grid()
+    abline(h=c(targetpower, fact*0.8, minpower), lty=3)
     segments(CVs[s], pwr[s], CVs[s+1], pwr[s+1], lwd=2, col=clr[s])
     points(CVs[1], pwr[1], col=clr[1], pch=16, cex=1.25)
     points(CVs[seg], pwr[seg], col=clr[seg], pch=16, cex=1.25)
-    text(CV, (minpower+(pwr.est-minpower)*0.1), 
-         labels=paste0("CV = ", signif(CV.max, 4), pctsign," (", 
+    text(CV, (minpower+(pwr.est-minpower)*0.1),
+         labels=paste0("CV = ", signif(CV.max, 4), pctsign," (",
                        round(minpower, dec), pctsign,")"), cex=0.9, pos=4)
   } else {
     # any scABE (including RSABE NTID)
     plot(CVs, pwr, type="n",
-         main=paste0("Lower/higher variability\n", "theta0 = ", GMR, ", n = ", n.est),
-         lwd=2, xlab=xlabtxt, ylab=ylabtxt, las=1)
-    abline(h=c(targetpower, 0.8*fact, minpower), lty=3, col="grey50")
+         main=paste0("Lower/higher variability\n",
+                     "constant: ", ratiolabel, " = ", GMR, ", N = ", n.est),
+         lwd=2, xlab=xlabtxt, ylab="", las=1)
+    grid()
+    abline(h=c(targetpower, 0.8*fact, minpower), lty=3)
+    mtext(side=2, ylabtxt, line=2.5)
     mklegend(x$method)
     box()
     segments(CVs[s], pwr[s], CVs[s+1], pwr[s+1], lwd=2, col=clr[s])
@@ -158,20 +164,20 @@ plot.pwrA <- function(x, pct=TRUE, cols=c("blue", "red"), ...)
     if (abs(pwr[seg]-minpower)/minpower<=1e-4){
       points(CVs[seg], pwr[seg], col=clr[seg], pch=16, cex=1.25)
     }
-    txt <- paste0("CV = ", signif(CV.max, 4), pctsign," (", round(minpower, dec)
-                  , pctsign,")")
+    txt <- paste0("CV = ", signif(CV.max, 4), pctsign, " (",
+                  round(minpower, dec), pctsign, ")")
     if  (x$method=="RSABE NTID"){
       if(abs(pwr[1]-minpower)/minpower<=1e-4) {
         #we have also CV.min with power=minpower
         points(CV.min, pwr[1], col=clr[seg], pch=16, cex=1.1)
         txt <- paste0("CV = (", signif(CV.min, 4),", ", signif(CV.max, 4),
-                      pctsign,") (",round(minpower, dec), pctsign,")")
+                      pctsign, ") (",round(minpower, dec), pctsign, ")")
       }
     }
-    text(min(CVs), (min(pwr)+(pwr.est-min(pwr))*0.1), labels=txt,
-         cex=0.8, pos=4)
+    text(min(CVs), (minpower+(max(pwr)-minpower)*0.1), labels=txt,
+         cex=0.9, pos=4)
   }
-  
+
   screen(2) ### 'Sensitivity' of GMR (CV and n constant) ###
   pwr <- as.numeric(fact*x$paGMR[,"pwr"])
   GMRs <- as.numeric(x$paGMR[,"theta0"])
@@ -179,24 +185,48 @@ plot.pwrA <- function(x, pct=TRUE, cols=c("blue", "red"), ...)
   GMR.min <- GMRs[1] # or better min(GMRs) or max(GMRs)?
   seg <- length(pwr); s <- seq(seg-1)
   clr  <- mkColors()
-  plot(GMRs, pwr, type="n", 
-       main=paste0("Larger deviation of theta0 from 1\n", "CV = ",
-                   CV, pctsign,", n = ", n.est), 
-       lwd=2, xlim=c(GMR, GMR.min), xlab="theta0", ylab=ylabtxt, las=1,
-       cex.main=0.95, cex.axis=0.95)
-  abline(h=c(targetpower, fact*0.8, minpower), lty=3, col="grey50")
-  mklegend(x$method)
-  box()
-  segments(GMRs[s], pwr[s], GMRs[s+1], pwr[s+1], lwd=2, col=clr[s])
-  # the next assumes that the values start at GMR and end on GMR.min (maybe also max!)
-  # TODO rework if plan.GMR not at border
-  points(GMRs[1], pwr[1], col=clr[1], pch=16, cex=1.25)
-  points(GMRs[seg], pwr[seg], col=clr[seg], pch=16, cex=1.25)
-  text(GMR, (minpower+(pwr.est-minpower)*0.1), 
-       labels=paste0("GMR = ",signif(GMR.min, 4), " (",
-                     round(minpower, dec), pctsign, ")"),
-       cex=0.85, pos=4)
-  
+  if (fact == 1) { # like in previous versions (ratio)
+    plot(GMRs, pwr, type="n",
+         main=paste0("Larger deviation from 1\n",
+                     "constant: CV = ", CV, pctsign,", N = ", n.est),
+         lwd=2, xlim=c(GMR, GMR.min), xlab=ratiolabel, ylab="", las=1,
+         cex.main=0.95, cex.axis=0.95)
+    grid()
+    abline(h=c(targetpower, fact*0.8, minpower), lty=3)
+    mklegend(x$method)
+    mtext(ylabtxt, side=2, line=2.5)
+    box()
+    segments(GMRs[s], pwr[s], GMRs[s+1], pwr[s+1], lwd=2, col=clr[s])
+    # the next assumes that the values start at GMR and end on GMR.min (maybe also max!)
+    # TODO rework if plan.GMR not at border
+    points(GMRs[1], pwr[1], col=clr[1], pch=16, cex=1.25)
+    points(GMRs[seg], pwr[seg], col=clr[seg], pch=16, cex=1.25)
+    text(GMR, (minpower+(pwr.est-minpower)*0.1),
+         labels=paste0(ratiolabel, " = ",signif(GMR.min, 4), " (",
+                       round(minpower, dec), pctsign, ")"),
+         cex=0.9, pos=4)
+  } else {
+    plot(100*GMRs, pwr, type="n",
+         main=paste0("Larger deviation from 100%\n",
+                     "constant: CV = ", CV, pctsign,", N = ", n.est),
+         lwd=2, xlim=100*c(GMR, GMR.min), xlab=paste(ratiolabel, "(%)"), ylab="", las=1,
+         cex.main=0.95, cex.axis=0.95)
+    grid()
+    abline(h=c(targetpower, fact*0.8, minpower), lty=3)
+    mklegend(x$method)
+    mtext(ylabtxt, side=2, line=2.5)
+    box()
+    segments(100*GMRs[s], pwr[s], 100*GMRs[s+1], pwr[s+1], lwd=2, col=clr[s])
+    # the next assumes that the values start at GMR and end on GMR.min (maybe also max!)
+    # TODO rework if plan.GMR not at border
+    points(100*GMRs[1], pwr[1], col=clr[1], pch=16, cex=1.25)
+    points(100*GMRs[seg], pwr[seg], col=clr[seg], pch=16, cex=1.25)
+    text(100*GMR, (minpower+(pwr.est-minpower)*0.1),
+         labels=paste0(ratiolabel, " = ",signif(100*GMR.min, 4), "% (",
+                       round(minpower, dec), pctsign, ")"),
+         cex=0.9, pos=4)    
+  }
+
   screen(3) ### Sensitivity of n (GMR and CV constant) ###
   pwr <- as.numeric(fact*x$paN[,"pwr"])
   Ns  <- as.numeric(x$paN[,"N"])
@@ -205,97 +235,138 @@ plot.pwrA <- function(x, pct=TRUE, cols=c("blue", "red"), ...)
   xticks <- NULL
   nNs    <- length(Ns)
   if(nNs<5 & nNs>1) xticks <- c(max(Ns), min(Ns), nNs-1)
-  plot(Ns, pwr, type="n", 
-       main=paste0("Drop-outs\n", "theta0 = ", GMR, ", CV = ", CV, pctsign),
+  plot(Ns, pwr, type="n",
+       main=paste0("Drop-outs\n",
+                   "constant: ", ratiolabel, " = ", GMR, ", CV = ", CV, pctsign),
        lwd=2, xlim=c(max(Ns), min(Ns)), ylim=c(minpower, pwr.est),
-       xlab="n", xaxp=xticks,
-       ylab=ylabtxt, las=1, cex.main=0.95)
-  abline(h=c(targetpower, fact*0.8, minpower), lty=3, col="grey50")
+       xlab="N", xaxp=xticks,
+       ylab="", las=1, cex.main=0.95)
+  grid()
+  abline(h=c(targetpower, fact*0.8, minpower), lty=3)
   mklegend(x$method)
+  mtext(side=2, ylabtxt, line=2.5)
   box()
   points(Ns, pwr, pch=16, cex=0.8, col=clr)
   points(Ns[length(Ns)], pwr[length(Ns)], col=clr[length(Ns)],
          pch=16, cex=1.25)
   points(n.est, pwr.est, col=clr[1], pch=16, cex=1.25)
-  text(max(Ns), (minpower+(pwr.est-minpower)*0.1), 
-       labels=paste0("n = ", min(Ns), " (", signif(min(pwr), 4), pctsign, ")"),
-       cex=0.85, pos=4)
-  
+  # label even drop-outs
+  do.even  <- Ns[c(TRUE, FALSE)]
+  pwr.even <- pwr[c(TRUE, FALSE)]
+  text(do.even, pwr.even, labels=n.est-do.even, pos=3, cex=0.75, offset=0.5)
+  text(max(Ns), (minpower+(pwr.est-minpower)*0.1),
+       labels=paste0("N = ", min(Ns), " (", signif(min(pwr), 4), pctsign, ")"),
+       cex=0.9, pos=4)
+
   screen(4) ### Some basic information ###
-  if (x$method!="RSABE NTID"){
-      CVtxt <- sprintf("  %s %+5.1f%%", "CV =",  100*(CV.max-CV)/CV)
+  if (x$method != "RSABE NTID"){
+    if (fact == 1) {
+      CVtxt <- sprintf("  CV = %.4f (%+5.1f%%)",
+                       CV.max, 100*(CV.max-CV)/CV)
+    } else {
+      CVtxt <- sprintf("  CV = %5.2f%% (%+5.1f%%)",
+                       CV.max, 100*(CV.max-CV)/CV)
+    }
   } else {
-      CVtxt <- ""
+      # CVtxt <- "" # why?
       if(abs(fact*x$paCV[1,"pwr"]-minpower)/minpower<=1e-4) {
-        #we have also CV.min with power=minpower
-        CVtxt <- sprintf("  %s %+5.1f%%", "CVmin =", 100*(CV.min-CV)/CV)
-        CVtxt <- c(CVtxt, sprintf("  %s %+5.1f%%", "CVmax =", 100*(CV.max-CV)/CV))
+        # we have also CV.min with power=minpower
+        if (fact == 1) {
+          CVtxt <- sprintf("  CVmin = %.5f (%+5.1f%%)", CV.min, 100*(CV.min-CV)/CV)
+          CVtxt <- c(CVtxt, sprintf("  CVmax = %.4f (%+5.1f%%)", CV.max, 100*(CV.max-CV)/CV))
+        } else {
+          CVtxt <- sprintf("  CVmin = %5.3f%% (%+5.1f%%)", CV.min, 100*(CV.min-CV)/CV)
+          CVtxt <- c(CVtxt, sprintf("  CVmax = %5.2f%% (%+5.1f%%)", CV.max, 100*(CV.max-CV)/CV))
+        }
       } else {
-        #we have only CV.max with power=minpower
-        CVtxt <- sprintf("  %s %+5.1f%%", "CV =", 100*(CV.max-CV)/CV)
+        # we have only CV.max with power=minpower
+        if (fact == 1) {
+          CVtxt <- sprintf("  CV = %.4f (%+5.1f%%)", CV.max, 100*(CV.max-CV)/CV)
+        } else {
+          CVtxt <- sprintf("  CV = %5.2f%% (%+5.1f%%)", CV.max, 100*(CV.max-CV)/CV)
+        }
       }
   }
-  if(x$method=="ABE"){
-    BEARtxt <- paste("BE AR: ", round(theta1,4),
-                     " ... ", round(theta2,4), sep="")
+  if (x$method=="ABE") {
+      BEARtxt <- "  BE margins:"
+    if (fact == 1) { # ratios
+      BEARtxt <- c(BEARtxt, sprintf("    %.4f %s %.4f",
+                                    theta1, "...", theta2))
+    } else { # percent
+      BEARtxt <- c(BEARtxt, sprintf("    %.2f%% %s %.2f%%",
+                                    100*theta1, "...", 100*theta2))
+    }
   }
   if(x$method=="scABE"){
     # (widened) acceptance range
     if(x$regulator=="FDA"){
-      Ltxt <-"implied BE AR: "
+      Ltxt <-"  implied BE margins:"
       wtheta1 <- min(theta1,exp(CV2se(CV/fact)*log(theta1)/0.25))
       wtheta2 <- max(theta2,exp(CV2se(CV/fact)*log(theta2)/0.25))
     } else { #EMA
-      Ltxt <- "(widened) BE AR: " 
+      Ltxt <- "  (widened) BE margins:"
       CVV <- min(0.5,CV/fact)      # cap
       wtheta1 <- min(theta1,exp(-CV2se(CVV)*0.76))
       wtheta2 <- max(theta2,exp(CV2se(CVV)*0.76))
     }
-    BEARtxt <- paste0(Ltxt, round(wtheta1,4),
-                     " ... ", round(wtheta2,4))
+    if (fact == 1) { # ratios
+      BEARtxt <- c(Ltxt, sprintf("    %.4f %s %.4f",
+                                 wtheta1, "...", wtheta2))
+    } else { # percent
+      BEARtxt <- c(Ltxt, sprintf("    %.2f%% %s %.2f%%",
+                                 100*wtheta1, "...", 100*wtheta2))
+    }
   }
   if(x$method=="RSABE NTID"){
-    Ltxt <-"implied BE AR: "
+    Ltxt <-"  implied BE margins:"
     wtheta1 <- max(theta1,exp(CV2se(CV/fact)*log(0.9)/0.1))
     wtheta2 <- min(theta2,exp(-CV2se(CV/fact)*log(0.9)/0.1))
-    BEARtxt <- paste0(Ltxt, round(wtheta1,4),
-                      " ... ", round(wtheta2,4))
-  }  
+    if (fact == 1) { # ratios
+      BEARtxt <- c(Ltxt, sprintf("    %.4f %s %.4f",
+                                 wtheta1, "...", wtheta2))
+    } else { # percent
+      BEARtxt <- c(Ltxt, sprintf("    %.2f%% %s %.2f%%",
+                                 100*wtheta1, "...", 100*wtheta2))
+    }
+  }
   plot(1, type="n", axes=F, xlab="", ylab="")
-  if (fact==100){
-    # percent
-    legend("topleft", 
+  if (fact == 100) { # percent
+    legend("topleft", inset=-0.065,
            legend=c(paste0(design, " design", "; assumed:"),
-                    sprintf("  %s %1.0f%%%s %5.4f", "CV =", CV, ", theta0 =", GMR),
+                    sprintf("  %s %1.0f%%%s%s%s %.2f%%", "CV =", CV, ", ", ratiolabel, " =", 100*GMR),
                     BEARtxt,
                     "power:",
                     sprintf("  %s %2.0f%%", "target =", targetpower),
                     sprintf("  %s %5.2f%% %s %i%s", "estimated =", pwr.est,
-                            "(n =", n.est, ")"),
+                            "(N =", n.est, ")"),
                     sprintf("  %s %2.0f%%", "minimum acceptable =", minpower),
-                    "acceptable rel. deviations:",
+                    "acceptable (relative) deviations:",
                     #TODO:react to RSABE NTID where there may be also a CVmin
                     CVtxt,
-                    sprintf("  %s %+5.2f%%", "GMR =", 100*(GMR.min-GMR)/GMR),
-                    sprintf("  %s %+5.1f%%", "n =",   100*(min(Ns)-n.est)/n.est)),
-           bty="n", cex=0.80)
-  } else {
-    # ratios
-    legend("topleft", 
+                    sprintf("  %s%s %5.2f%% (%+5.2f%%)",
+                            ratiolabel, " =", 100*GMR.min, 100*(GMR.min-GMR)/GMR),
+                    sprintf("  %s %i (%+5.1f%%)",
+                            "N =", min(Ns), 100*(min(Ns)-n.est)/n.est)),
+           bty="n", cex=0.9)
+  } else { # ratios
+    legend("topleft", inset=-0.065,
            legend=c(paste0(design, " design", "; assumed:"),
-                    sprintf("  %s %5.4f%s %5.4f", "CV =", CV, ", theta0 =", GMR),
+                    sprintf("  %s %5.4f%s%s%s %.4f", "CV =", CV, ", ", ratiolabel, " =", GMR),
+                    BEARtxt,
                     "power:",
                     sprintf("  %s %5.4f", "target =", targetpower),
                     sprintf("  %s %5.4f %s %i%s", "estimated =", pwr.est,
-                            "(n =", n.est, ")"),
+                            "(N =", n.est, ")"),
                     sprintf("  %s %5.4f", "minimum acceptable =", minpower),
-                    "acceptable rel. deviations:",
+                    "acceptable (relative) deviations:",
                     CVtxt,
-                    sprintf("  %s %+5.2f%%", "GMR =", 100*(GMR.min-GMR)/GMR),
-                    sprintf("  %s %+5.1f%%", "n =",   100*(min(Ns)-n.est)/n.est)),
-           bty="n", cex=0.85)
+                    sprintf("  %s%s %.4f (%+5.2f%%)",
+                            ratiolabel, " =", GMR.min, 100*(GMR.min-GMR)/GMR),
+                    sprintf("  %s %i (%+5.1f%%)",
+                            "N =", min(Ns), 100*(min(Ns)-n.est)/n.est)),
+           bty="n", cex=0.9)
   }
-  
+
   close.screen(all.screens=TRUE)
   par(op) #reset options
-}
\ No newline at end of file
+}
